@@ -415,17 +415,17 @@ static const guint8 folder_rgba[] =
   "!(\40\366ZiX\377\222\241\220\376\247\265\245\3777B6\377$'$\377/6/\377"
   "\0\0\0\354\1\1\1\316\0\0\0\243\0\0\0X\0\0\0\30\0\0\0\2\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0\23\0"
-  "\1\0?\0\0\1\222\31\34\30\355AM?\377n\177l\376MZL\376*/)\377\13\15\12"
-  "\374\0\0\0\330\0\0\0\250\0\0\0c\0\0\0%\0\0\0\7\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0"
-  "\0\0\17\0\0\0/\0\0\0w\30\33\30\3323<1\377\40&\37\377\14\16\14\377\0\0"
-  "\0\335\0\0\0\234\0\0\0X\0\0\0\40\0\0\0\7\0\0\0\1\0\0\0\0\0\0\0\0\0\0"
+  "\1\0\77\0\0\1\222\31\34\30\355AM\77\377n\177l\376MZL\376*/)\377\13\15"
+  "\12\374\0\0\0\330\0\0\0\250\0\0\0c\0\0\0%\0\0\0\7\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1"
+  "\0\0\0\17\0\0\0/\0\0\0w\30\33\30\3323<1\377\40&\37\377\14\16\14\377\0"
+  "\0\0\335\0\0\0\234\0\0\0X\0\0\0\40\0\0\0\7\0\0\0\1\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\2\0\0\0\14\0\0\0\36\1\0\0T\1\1\2\227\0\0\0\276\0\0\0\264\0\0\0"
-  "\177\0\0\0B\0\0\0\27\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0"
-  "\0\0\0\0\0\5\0\0\0\10\0\0\0\16\0\0\0#\1\1\1""9\1\1\1""6\0\0\0\36\0\0"
-  "\0\11\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};
+  "\0\0\0\0\2\0\0\0\14\0\0\0\36\1\0\0T\1\1\2\227\0\0\0\276\0\0\0\264\0\0"
+  "\0\177\0\0\0B\0\0\0\27\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0"
+  "\0\0\0\0\0\0\5\0\0\0\10\0\0\0\16\0\0\0#\1\1\1""9\1\1\1""6\0\0\0\36\0"
+  "\0\0\11\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};
 
 
 /* GdkPixbuf RGBA C-Source image dump */
