@@ -34,9 +34,14 @@
 #include "preferences.h"
 #include "main.h"
 
-static void prepare_app     (poptContext pctx);
-static void initialize_data ();
-static void release_data    ();
+static void     prepare_app         (poptContext pctx);
+static void     initialize_data     (void);
+static void     release_data        (void);
+
+static void     init_session        (char **argv);
+static gboolean session_is_restored (void);
+static gboolean load_session        (void);
+
 
 GList        *window_list = NULL;
 GList        *viewer_list = NULL;
@@ -49,12 +54,6 @@ static gchar *extract_to = NULL;
 static gint   extract;
 static gchar *default_url = NULL;
 
-#define N_SCRIPTS 4
-static char *script[N_SCRIPTS] = { "Add_to_archive", 
-				   "Extract_here", 
-				   "Extract_in_a_subfolder", 
-				   "Extract_to" };
-
 struct poptOption options[] = {
 	{ "add-to", 'a', POPT_ARG_STRING, &add_to, 0,
 	  N_("Add files to the specified archive and quit the program"),
@@ -83,6 +82,7 @@ struct poptOption options[] = {
 	{ NULL, '\0', 0, NULL, 0 }
 };
 
+
 /* -- Main -- */
 
 int main (int argc, char **argv)
@@ -113,9 +113,13 @@ int main (int argc, char **argv)
 
 	if (! gnome_vfs_init ()) 
                 g_error ("Cannot initialize the Virtual File System.");
+
 	glade_gnome_init ();
 
+	init_session (argv);
+
 	initialize_data ();
+
 	prepare_app (pctx);
 	poptFreeContext (pctx);
 
@@ -129,79 +133,6 @@ int main (int argc, char **argv)
 /* Initialize application data. */
 
 
-void
-install_scripts ()
-{
-	char *src_dir;
-	char *dest_dir;
-	int   i;
-
-	src_dir = g_strconcat (FR_DATADIR, 
-			       "/file-roller/scripts", 
-			       NULL);
-	dest_dir = g_strconcat (g_get_home_dir (), 
-				"/.gnome2/nautilus-scripts",
-				NULL);
-
-	ensure_dir_exists (dest_dir, 0700);
-
-	for (i = 0; i < N_SCRIPTS; i++) {
-		char *line;
-		char *name_with_spaces;
-		int   j;
-
-		name_with_spaces = g_strdup (script[i]);
-
-		for (j = 0; name_with_spaces[j] != 0; j++)
-			if (name_with_spaces[j] == '_')
-				name_with_spaces[j] = ' ';
-
-		line = g_strdup_printf ("cp %s/%s \"%s/%s\"\n", 
-					src_dir, 
-					script[i], 
-					dest_dir,
-					name_with_spaces);
-		system (line);
-		g_free (line);
-
-		line = g_strdup_printf ("chmod 0700 \"%s/%s\"\n", 
-					dest_dir, 
-					name_with_spaces);
-		system (line);
-		g_free (line);
-
-		g_free (name_with_spaces);
-	}
-
-	g_free (src_dir);
-	g_free (dest_dir);
-
-	eel_gconf_set_boolean (PREF_INSTALL_SCRIPTS, FALSE);
-}
-
-
-void
-remove_scripts ()
-{
-	char *dest_dir;
-	int   i;
-
-	dest_dir = g_strconcat (g_get_home_dir (), 
-				"/.gnome2/nautilus-scripts",
-				NULL);
-
-	for (i = 0; i < N_SCRIPTS; i++) {
-		char *line;
-
-		line = g_strdup_printf ("rm -f %s/%s\n", dest_dir, script[i]);
-		system (line);
-		g_free (line);
-	}
-
-	g_free (dest_dir);
-}
-
-
 static void 
 initialize_data ()
 {
@@ -213,9 +144,6 @@ initialize_data ()
 		gnome_window_icon_set_default_from_file (icon_path);
 
 	eel_gconf_monitor_add ("/apps/file-roller");
-
-	if (eel_gconf_get_boolean (PREF_INSTALL_SCRIPTS))
-		install_scripts ();
 }
 
 /* Free application data. */
@@ -316,6 +244,77 @@ get_path_from_url (char *url)
 }
 
 
+static void
+migrate_dir_from_to (const char *from_dir,
+                     const char *to_dir)
+{
+        char *from_path;
+        char *to_path;
+
+        from_path = get_home_relative_dir (from_dir);
+        to_path = get_home_relative_dir (to_dir);
+
+        if (path_is_dir (from_path) && ! path_is_dir (to_path)) {
+                char *line;
+                char *e1;
+                char *e2;
+
+                e1 = shell_escape (from_path);
+                e2 = shell_escape (to_path);
+                line = g_strdup_printf ("mv -f %s %s", e1, e2);
+                g_free (e1);
+                g_free (e2);
+
+                g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);  
+                g_free (line);
+        }
+
+        g_free (from_path);
+        g_free (to_path);
+}
+
+
+static void
+migrate_file_from_to (const char *from_file,
+                      const char *to_file)
+{
+        char *from_path;
+        char *to_path;
+
+        from_path = get_home_relative_dir (from_file);
+        to_path = get_home_relative_dir (to_file);
+
+        if (path_is_file (from_path) && ! path_is_file (to_path)) {
+                char *line;
+                char *e1;
+                char *e2;
+
+                e1 = shell_escape (from_path);
+                e2 = shell_escape (to_path);
+                line = g_strdup_printf ("mv -f %s %s", e1, e2);
+                g_free (e1);
+                g_free (e2);
+
+                g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);  
+                g_free (line);
+        }
+
+        g_free (from_path);
+        g_free (to_path);
+}
+
+
+static void
+migrate_to_new_directories (void)
+{
+	migrate_dir_from_to  (OLD_RC_OPTIONS_DIR, RC_OPTIONS_DIR);
+	migrate_file_from_to (OLD_RC_BOOKMARKS_FILE, RC_BOOKMARKS_FILE);
+        migrate_file_from_to (OLD_RC_RECENT_FILE, RC_RECENT_FILE);
+
+	eel_gconf_set_boolean (PREF_MIGRATE_DIRECTORIES, FALSE);
+}
+
+
 static void 
 prepare_app (poptContext pctx)
 {
@@ -326,10 +325,18 @@ prepare_app (poptContext pctx)
 
 	/* create the config dir if necessary. */
 
-	path = g_strconcat (g_get_home_dir (), "/.file-roller", NULL);
+	path = get_home_relative_dir (RC_DIR);
 	ensure_dir_exists (path, 0700);
 	g_free (path);
 
+	if (eel_gconf_get_boolean (PREF_MIGRATE_DIRECTORIES))
+                migrate_to_new_directories ();
+
+	if (session_is_restored ()) {
+		load_session ();
+		return;
+	}
+
 	/**/
 
 	if (poptPeekArg (pctx) == NULL) { /* No archive specified. */
@@ -406,3 +413,156 @@ prepare_app (poptContext pctx)
 	g_free (add_to_path);
         g_free (extract_to_path);
 }
+
+
+ /* SM support */
+
+
+/* The master client we use for SM */
+static GnomeClient *master_client = NULL;
+
+/* argv[0] from main(); used as the command to restart the program */
+static const char *program_argv0 = NULL;
+
+
+static void
+save_session (GnomeClient *client)
+{
+	const char  *prefix;
+	GList        *scan;
+	int          i = 0;
+
+	prefix = gnome_client_get_config_prefix (client);
+	gnome_config_push_prefix (prefix);
+
+	for (scan = window_list; scan; scan = scan->next) {
+		FRWindow *window = scan->data;
+		char     *key;
+
+		if ((window->archive == NULL) 
+		    || (window->archive->filename == NULL))
+			continue;
+
+		key = g_strdup_printf ("Session/archive%d", i);
+		gnome_config_set_string (key, window->archive->filename);
+		g_free (key);
+
+		i++;
+	}
+
+	gnome_config_set_int ("Session/archives", i);
+
+	gnome_config_pop_prefix ();
+	gnome_config_sync ();
+}
+
+
+/* save_yourself handler for the master client */
+static gboolean
+client_save_yourself_cb (GnomeClient *client,
+			 gint phase,
+			 GnomeSaveStyle save_style,
+			 gboolean shutdown,
+			 GnomeInteractStyle interact_style,
+			 gboolean fast,
+			 gpointer data)
+{
+	const char *prefix;
+	char       *argv[4] = { NULL };
+
+	save_session (client);
+
+	prefix = gnome_client_get_config_prefix (client);
+
+	/* Tell the session manager how to discard this save */
+
+	argv[0] = "rm";
+	argv[1] = "-rf";
+	argv[2] = gnome_config_get_real_path (prefix);
+	argv[3] = NULL;
+	gnome_client_set_discard_command (client, 3, argv);
+
+	/* Tell the session manager how to clone or restart this instance */
+
+	argv[0] = (char *) program_argv0;
+	argv[1] = NULL; /* "--debug-session"; */
+	
+	gnome_client_set_clone_command (client, 1, argv);
+	gnome_client_set_restart_command (client, 1, argv);
+
+	return TRUE;
+}
+
+/* die handler for the master client */
+static void
+client_die_cb (GnomeClient *client, gpointer data)
+{
+	if (! client->save_yourself_emitted)
+		save_session (client);
+
+	gtk_main_quit ();
+}
+
+
+static void
+init_session (char **argv)
+{
+	if (master_client != NULL)
+		return;
+
+	program_argv0 = argv[0];
+
+	master_client = gnome_master_client ();
+
+	g_signal_connect (master_client, "save_yourself",
+			  G_CALLBACK (client_save_yourself_cb),
+			  NULL);
+
+	g_signal_connect (master_client, "die",
+			  G_CALLBACK (client_die_cb),
+			  NULL);
+}
+
+
+gboolean
+session_is_restored (void)
+{
+	gboolean restored;
+	
+	if (! master_client)
+		return FALSE;
+
+	restored = (gnome_client_get_flags (master_client) & GNOME_CLIENT_RESTORED) != 0;
+
+	return restored;
+}
+
+
+gboolean
+load_session (void)
+{
+	int i, n;
+	
+	gnome_config_push_prefix (gnome_client_get_config_prefix (master_client));
+
+	n = gnome_config_get_int ("Session/archives");
+	for (i = 0; i < n; i++) {
+		FRWindow *window;
+		char     *key;
+		char     *filename;
+
+		key = g_strdup_printf ("Session/archive%d", i);
+		filename = gnome_config_get_string (key);
+		g_free (key);
+
+		window = window_new ();
+		gtk_widget_show (window->app);
+		window_archive_open (window, filename);
+
+		g_free (filename);
+	}
+
+	gnome_config_pop_prefix ();
+
+	return TRUE;
+}
